"""Module to hold dataclass or related data used in Bluetooth operations."""

import dataclasses
from bttc import constants
from typing import Any


@dataclasses.dataclass
class BondedDeviceInfo:
  """Information of a bonded device."""

  mac_addr: str
  bt_type: constants.BluetoothDeviceType
  name: str


@dataclasses.dataclass
class PairedDeviceInfo:
  """Information of a paired device."""

  mac_addr: str
  bt_type: constants.BluetoothDeviceType
  name: str
  uuids: list[str]
  bond_state: constants.BluetoothBondedState

  @classmethod
  def from_dict(
      cls, dict_data: dict[str, Any]) -> 'PairedDeviceInfo':
    name = dict_data['Name']

    # 'DEVICE_TYPE_DUAL' -> 'DUAL'
    bt_type = constants.BluetoothDeviceType.from_str(
        dict_data['DeviceType'].split('_')[-1])

    mac_addr = dict_data['Address']
    uuids = dict_data['UUIDs']
    bond_state = constants.BluetoothBondedState.from_str(
        dict_data['BondState'].split('_')[-1])

    return PairedDeviceInfo(
        mac_addr=mac_addr,
        bt_type=bt_type,
        name=name,
        uuids=uuids,
        bond_state=bond_state)
